import { MatrixClient, MatrixEvent } from "matrix-js-sdk/src/matrix";
import { TypedEventEmitter } from "matrix-js-sdk/src/models/typed-event-emitter";
import { VoiceBroadcastInfoState } from "..";
import { IDestroyable } from "../../utils/IDestroyable";
export declare enum VoiceBroadcastRecordingEvent {
    StateChanged = "liveness_changed",
    TimeLeftChanged = "time_left_changed"
}
interface EventMap {
    [VoiceBroadcastRecordingEvent.StateChanged]: (state: VoiceBroadcastInfoState) => void;
    [VoiceBroadcastRecordingEvent.TimeLeftChanged]: (timeLeft: number) => void;
}
export declare class VoiceBroadcastRecording extends TypedEventEmitter<VoiceBroadcastRecordingEvent, EventMap> implements IDestroyable {
    readonly infoEvent: MatrixEvent;
    private client;
    private state;
    private recorder;
    private dispatcherRef;
    private chunkEvents;
    private chunkRelationHelper;
    private maxLength;
    private timeLeft;
    /**
     * Broadcast chunks have a sequence number to bring them in the correct order and to know if a message is missing.
     * This variable holds the last sequence number.
     * Starts with 0 because there is no chunk at the beginning of a broadcast.
     * Will be incremented when a chunk message is created.
     */
    private sequence;
    constructor(infoEvent: MatrixEvent, client: MatrixClient, initialState?: VoiceBroadcastInfoState);
    private initialiseChunkEventRelation;
    private onChunkEvent;
    private setInitialStateFromInfoEvent;
    getTimeLeft(): number;
    private setTimeLeft;
    start(): Promise<void>;
    stop(): Promise<void>;
    pause(): Promise<void>;
    resume(): Promise<void>;
    toggle: () => Promise<void>;
    getState(): VoiceBroadcastInfoState;
    private getRecorder;
    destroy(): Promise<void>;
    private onBeforeRedaction;
    private onAction;
    private setState;
    private onCurrentChunkLengthUpdated;
    private onChunkRecorded;
    private uploadFile;
    private sendVoiceMessage;
    private sendInfoStateEvent;
    private stopRecorder;
}
export {};
